package com.bonus.system.mapper;

import com.bonus.system.domain.SysIpWhitelist;

import java.util.List;

/**
 * 白名单管理Mapper接口
 *
 * @author bonus
 * @date 2024-11-06
 */
public interface SysIpWhitelistMapper
{
    /**
     * 查询白名单管理
     *
     * @param id 白名单管理主键
     * @return 白名单管理
     */
    public SysIpWhitelist selectSysIpWhitelistById(Long id);

    /**
     * 查询白名单管理列表
     *
     * @param sysIpWhitelist 白名单管理
     * @return 白名单管理集合
     */
    public List<SysIpWhitelist> selectSysIpWhitelistList(SysIpWhitelist sysIpWhitelist);

    /**
     * 新增白名单管理
     *
     * @param sysIpWhitelist 白名单管理
     * @return 结果
     */
    public int insertSysIpWhitelist(SysIpWhitelist sysIpWhitelist);

    /**
     * 修改白名单管理
     *
     * @param sysIpWhitelist 白名单管理
     * @return 结果
     */
    public int updateSysIpWhitelist(SysIpWhitelist sysIpWhitelist);

    /**
     * 删除白名单管理
     *
     * @param id 白名单管理主键
     * @return 结果
     */
    public int deleteSysIpWhitelistById(Long id);

    /**
     * 批量删除白名单管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysIpWhitelistByIds(Long[] ids);

    public int updateSysIpWhitelistStatus(SysIpWhitelist sysIpWhitelist);

    public List<SysIpWhitelist> selectSysIpWhitelist();
}
